Author: yamakenz
Date: Wed Jul 11 06:07:04 2007
New Revision: 4708

Modified:
   trunk/doc/COMPATIBILITY
   trunk/scm/anthy-utf8.scm
   trunk/scm/anthy.scm
   trunk/scm/byeoru.scm
   trunk/scm/canna.scm
   trunk/scm/custom.scm
   trunk/scm/ichar.scm
   trunk/scm/look.scm
   trunk/scm/m17nlib.scm
   trunk/scm/mana.scm
   trunk/scm/skk.scm
   trunk/test/test-util.scm

Log:
* This commit rename integer-based char-* procedures to ichar-* to
  distinguish from and coexist with R5RS ones. The renamings are
  performed by following script

  $ perl -i -pe 
's/\bchar-(control\?|upper-case\?|lower-case\?|alphabetic\?|numeric\?|printable\?|graphic\?|vowel\?|consonant\?|downcase\b|upcase\b)/ichar-\1/g'
 {scm,test}/*.scm

* scm/ichar.scm
  - (char-control?, char-upper-case?, char-lower-case?,
    char-alphabetic?, char-numeric?, char-printable?, char-graphic?,
    char-vowel?, char-consonant?, char-downcase, char-upcase): Renamed
    to ichar-*
  - (ichar-control?, ichar-upper-case?, ichar-lower-case?,
    ichar-alphabetic?, ichar-numeric?, ichar-printable?, ichar-graphic?,
    ichar-vowel?, ichar-consonant?, ichar-downcase, ichar-upcase):
    * Renamed from char-*
    * Follow the renamings
  - (string->printable-char, string->letter, numeral-char->number,
    control-char?, alphabet-char?, numeral-char?, usual-char?,
    to-lower-char): Follow the renamings
* scm/anthy-utf8.scm
* scm/anthy.scm
* scm/byeoru.scm
* scm/canna.scm
* scm/custom.scm
* scm/look.scm
* scm/m17nlib.scm
* scm/mana.scm
* scm/skk.scm
  - Follow the renamings
* test/test-util.scm
  - Ditto
  - Update the "passed revision" comment
* doc/COMPATIBILITY
  - Add new entry "Renaming of integer-based char procedures"


Modified: trunk/doc/COMPATIBILITY
==============================================================================
--- trunk/doc/COMPATIBILITY     (original)
+++ trunk/doc/COMPATIBILITY     Wed Jul 11 06:07:04 2007
@@ -57,6 +57,42 @@
 
 The changes are described below in most recently updated order.
 ------------------------------------------------------------------------------
+Summary: Renaming of integer-based char procedures
+Affects: uim developers, IM developers
+Updates: Scheme API
+Version: 1.5.0
+Revision: ac4708
+Date: 2007-07-11
+Modifier: YamaKen
+Related: 
+URL:
+Changes:
+  (renamed) char-control?
+  (renamed) char-upper-case?
+  (renamed) char-lower-case?
+  (renamed) char-alphabetic?
+  (renamed) char-numeric?
+  (renamed) char-printable?
+  (renamed) char-graphic?
+  (renamed) char-vowel?
+  (renamed) char-consonant?
+  (renamed) char-downcase
+  (renamed) char-upcase
+      (new) ichar-control?
+      (new) ichar-upper-case?
+      (new) ichar-lower-case?
+      (new) ichar-alphabetic?
+      (new) ichar-numeric?
+      (new) ichar-printable?
+      (new) ichar-graphic?
+      (new) ichar-vowel?
+      (new) ichar-consonant?
+      (new) ichar-downcase
+      (new) ichar-upcase
+Description:
+  The integer-based char-* procedures have been renamed to ichar-* to
+  distinguish from and coexist with R5RS ones
+------------------------------------------------------------------------------
 Summary: Specification changes of utility procedures
 Affects: uim developers, IM developers
 Updates: Scheme API

Modified: trunk/scm/anthy-utf8.scm
==============================================================================
--- trunk/scm/anthy-utf8.scm    (original)
+++ trunk/scm/anthy-utf8.scm    Wed Jul 11 06:07:04 2007
@@ -416,8 +416,8 @@
              (if upper?
                  (map
                   (lambda (x)
-                    (if (char-alphabetic? (string->charcode x))
-                        (charcode->string (char-upcase (string->charcode x)))
+                    (if (ichar-alphabetic? (string->charcode x))
+                        (charcode->string (ichar-upcase (string->charcode x)))
                         x))
                   (string-to-list (car raw-str-list)))
                  (string-to-list (car raw-str-list))))
@@ -427,8 +427,8 @@
                 (string-list-concat
                  (map
                   (lambda (x)
-                    (if (char-alphabetic? (string->charcode x))
-                        (charcode->string (char-upcase (string->charcode x)))
+                    (if (ichar-alphabetic? (string->charcode x))
+                        (charcode->string (ichar-upcase (string->charcode x)))
                         x))
                   (string-to-list (car raw-str-list))))
                 (car raw-str-list))
@@ -1025,7 +1025,7 @@
              (if (and
                   (= (anthy-utf8-context-input-rule ac) anthy-input-rule-roma)
                   (not (null? (ustr-former-seq preconv-str)))
-                  (not (char-printable?        ;; check for kana
+                  (not (ichar-printable?       ;; check for kana
                         (string->char
                          (car (last (ustr-former-seq preconv-str)))))))
                  (ja-fix-deleted-raw-str-to-valid-roma! raw-str)))))

Modified: trunk/scm/anthy.scm
==============================================================================
--- trunk/scm/anthy.scm (original)
+++ trunk/scm/anthy.scm Wed Jul 11 06:07:04 2007
@@ -411,8 +411,8 @@
              (if upper?
                  (map
                   (lambda (x)
-                    (if (char-alphabetic? (string->charcode x))
-                        (charcode->string (char-upcase (string->charcode x)))
+                    (if (ichar-alphabetic? (string->charcode x))
+                        (charcode->string (ichar-upcase (string->charcode x)))
                         x))
                   (string-to-list (car raw-str-list)))
                  (string-to-list (car raw-str-list))))
@@ -422,8 +422,8 @@
                 (string-list-concat
                  (map
                   (lambda (x)
-                    (if (char-alphabetic? (string->charcode x))
-                        (charcode->string (char-upcase (string->charcode x)))
+                    (if (ichar-alphabetic? (string->charcode x))
+                        (charcode->string (ichar-upcase (string->charcode x)))
                         x))
                   (string-to-list (car raw-str-list))))
                 (car raw-str-list))
@@ -1020,7 +1020,7 @@
              (if (and
                   (= (anthy-context-input-rule ac) anthy-input-rule-roma)
                   (not (null? (ustr-former-seq preconv-str)))
-                  (not (char-printable?        ;; check for kana
+                  (not (ichar-printable?       ;; check for kana
                         (string->char
                          (car (last (ustr-former-seq preconv-str)))))))
                  (ja-fix-deleted-raw-str-to-valid-roma! raw-str)))))

Modified: trunk/scm/byeoru.scm
==============================================================================
--- trunk/scm/canna.scm (original)
+++ trunk/scm/canna.scm Wed Jul 11 06:07:04 2007
@@ -366,7 +366,7 @@
             (ja-string-list-to-wide-alphabet
              (if upper?
                  (map charcode->string
-                      (map char-upcase
+                      (map ichar-upcase
                            (map string->charcode
                                 (string-to-list (car raw-str-list)))))
                  (string-to-list (car raw-str-list))))
@@ -375,7 +375,7 @@
             (if upper?
                 (string-list-concat
                  (map charcode->string
-                      (map char-upcase
+                      (map ichar-upcase
                            (map string->charcode
                                 (string-to-list (car raw-str-list))))))
                 (car raw-str-list))
@@ -736,7 +736,7 @@
            (if (and
                 (= (canna-context-input-rule cc) canna-input-rule-roma)
                 (not (null? (ustr-former-seq preconv-str)))
-                (not (char-printable?
+                (not (ichar-printable?
                       (string->char
                        (car (last (ustr-former-seq preconv-str)))))))
                (ja-fix-deleted-raw-str-to-valid-roma! raw-str)))))

Modified: trunk/scm/custom.scm
==============================================================================
--- trunk/scm/custom.scm        (original)
+++ trunk/scm/custom.scm        Wed Jul 11 06:07:04 2007
@@ -201,12 +201,12 @@
 ;; TODO: write test
 (define key-list-upcase
   (lambda (key-list)
-    (map-key-list-letter char-upcase key-list)))
+    (map-key-list-letter ichar-upcase key-list)))
 
 ;; TODO: write test
 (define key-list-downcase
   (lambda (key-list)
-    (map-key-list-letter char-downcase key-list)))
+    (map-key-list-letter ichar-downcase key-list)))
 
 ;; TODO: write test
 (define key-list-visualize-space
@@ -236,15 +236,15 @@
       (filter-map (lambda (elem)
                    (cond
                     ((and (eq? elem 'Shift_key)
-                          (char-graphic? printable))
+                          (ichar-graphic? printable))
                      #f)
                     ((and (string? elem)
                           has-shift?
                           letter)
-                     (charcode->string (char-upcase letter)))
+                     (charcode->string (ichar-upcase letter)))
                     ((and (string? elem)
                           has-shift?
-                          (char-graphic? printable))
+                          (ichar-graphic? printable))
                      str)
                     (else
                      elem)))
@@ -255,7 +255,7 @@
   (lambda (key-list)
     (let* ((letter (string->letter (find string? key-list)))
           (upper-case? (and letter
-                            (char-upper-case? letter)))
+                            (ichar-upper-case? letter)))
           (has-shift? (memq 'Shift_key key-list))
           (stripped (key-list-downcase key-list)))
       (if (and (not has-shift?)
@@ -267,7 +267,7 @@
 (define key-list-ignore-regular-shift
   (lambda (key-list)
     (let ((printable (string->printable-char (find string? key-list))))
-      (if (char-graphic? printable)
+      (if (ichar-graphic? printable)
          (cons 'IgnoreRegularShift key-list)
          key-list))))
 
@@ -284,8 +284,8 @@
   (lambda (key-list)
     (let* ((str (find string? key-list))
           (c (string->printable-char str)))
-      (if (and (char-graphic? c)
-              (not (char-alphabetic? c)))
+      (if (and (ichar-graphic? c)
+              (not (ichar-alphabetic? c)))
          (cons 'IgnoreShift key-list)
          key-list))))
 
@@ -307,7 +307,7 @@
   (lambda (key-list)
     (let* ((str (find string? key-list))
           (printable (string->printable-char str)))
-      (if (char-graphic? printable)
+      (if (ichar-graphic? printable)
          (key-list-strip-shift key-list)
          key-list))))
 

Modified: trunk/scm/ichar.scm
==============================================================================
--- trunk/scm/ichar.scm (original)
+++ trunk/scm/ichar.scm Wed Jul 11 06:07:04 2007
@@ -42,89 +42,89 @@
 (define string->printable-char
   (lambda (str)
     (let ((c (string->char str)))
-      (and (char-printable? c)
+      (and (ichar-printable? c)
           c))))
 
 (define string->letter
   (lambda (str)
     (let ((c (string->printable-char str)))
-      (and (char-alphabetic? c)
+      (and (ichar-alphabetic? c)
           c))))
 
 ;;
 ;; R5RS-like character procedures
 ;;
 
-(define char-control?
+(define ichar-control?
   (lambda (c)
     (and (integer? c)
         (or (<= c 31)
             (= c 127)))))
 
-(define char-upper-case?
+(define ichar-upper-case?
   (lambda (c)
     (and (integer? c)
         (>= c 65)
         (<= c 90))))
 
-(define char-lower-case?
+(define ichar-lower-case?
   (lambda (c)
     (and (integer? c)
         (>= c 97)
         (<= c 122))))
 
-(define char-alphabetic?
+(define ichar-alphabetic?
   (lambda (c)
-    (or (char-upper-case? c)
-       (char-lower-case? c))))
+    (or (ichar-upper-case? c)
+       (ichar-lower-case? c))))
 
-(define char-numeric?
+(define ichar-numeric?
   (lambda (c)
     (and (integer? c)
         (>= c 48)
         (<= c 57))))
 
-(define char-printable?
+(define ichar-printable?
   (lambda (c)
     (and (integer? c)
         (<= c 127)
-        (not (char-control? c)))))
+        (not (ichar-control? c)))))
 
-(define char-graphic?
+(define ichar-graphic?
   (lambda (c)
-    (and (char-printable? c)
+    (and (ichar-printable? c)
         (not (= c 32)))))
 
 ;; TODO: write test
-(define char-vowel?
+(define ichar-vowel?
   (let ((vowel-chars (map char->integer
                          '(#\a #\i #\u #\e #\o))))
     (lambda (c)
-      (and (char-alphabetic? c)
-          (member (char-downcase c)
+      (and (ichar-alphabetic? c)
+          (member (ichar-downcase c)
                   vowel-chars)))))
 
 ;; TODO: write test
-(define char-consonant?
+(define ichar-consonant?
   (lambda (c)
-    (and (char-alphabetic? c)
-        (not (char-vowel? c)))))
+    (and (ichar-alphabetic? c)
+        (not (ichar-vowel? c)))))
 
 (define numeral-char->number
   (lambda (c)
-    (if (char-numeric? c)
+    (if (ichar-numeric? c)
        (- c 48)
        c)))
 
-(define char-downcase
+(define ichar-downcase
   (lambda (c)
-    (if (char-upper-case? c)
+    (if (ichar-upper-case? c)
        (+ c 32)
        c)))
 
-(define char-upcase
+(define ichar-upcase
   (lambda (c)
-    (if (char-lower-case? c)
+    (if (ichar-lower-case? c)
        (- c 32)
        c)))
 
@@ -132,11 +132,11 @@
 ;; backward compatibility: should be obsoleted
 ;;
 
-(define control-char? char-control?)
-(define alphabet-char? char-alphabetic?)
-(define numeral-char? char-numeric?)
-(define usual-char? char-graphic?)
-(define to-lower-char char-downcase)
+(define control-char? ichar-control?)
+(define alphabet-char? ichar-alphabetic?)
+(define numeral-char? ichar-numeric?)
+(define usual-char? ichar-graphic?)
+(define to-lower-char ichar-downcase)
 
 (define charcode->string
   (lambda (c)

Modified: trunk/scm/look.scm
==============================================================================
--- trunk/scm/look.scm  (original)
+++ trunk/scm/look.scm  Wed Jul 11 06:07:04 2007
@@ -137,7 +137,7 @@
 (define (look-to-lower-string str)
   (apply string-append
          (map (lambda (c)
-                (if (char-upper-case? (string->charcode c))
+                (if (ichar-upper-case? (string->charcode c))
                     (charcode->string (to-lower-char (string->charcode c)))
                     c))
               (reverse (string-to-list str)))))
@@ -381,7 +381,7 @@
 (define (look-alphabetic-char? key state)
   (and (or (not (modifier-key-mask state))
            (shift-key-mask state))
-       (char-alphabetic? key)))
+       (ichar-alphabetic? key)))
 
 (define (look-next-candidate! lc)
   (if (< (look-context-nth lc) (- (length (look-context-candidates lc)) 1))

Modified: trunk/scm/m17nlib.scm
==============================================================================
--- trunk/scm/m17nlib.scm       (original)
+++ trunk/scm/m17nlib.scm       Wed Jul 11 06:07:04 2007
@@ -179,11 +179,11 @@
     (let ((key-str ""))
       (if (and
           (shift-key-mask key-state)
-          (not (char-graphic? key)))
+          (not (ichar-graphic? key)))
          (set! key-str (string-append "S-" key-str)))
       (if (and
           (control-key-mask key-state)
-          (char-printable? key))
+          (ichar-printable? key))
          (set! key-str (string-append "C-" key-str)))
       (if (alt-key-mask key-state)
          (set! key-str (string-append "A-" key-str)))
@@ -203,7 +203,7 @@
              (cdr mkey)
              ""))
        (if (control-key-mask key-state)
-           (charcode->string (char-upcase key))
+           (charcode->string (ichar-upcase key))
            (charcode->string key)))))
 
 (define m17nlib-proc-direct-state

Modified: trunk/scm/mana.scm
==============================================================================
--- trunk/scm/mana.scm  (original)
+++ trunk/scm/mana.scm  Wed Jul 11 06:07:04 2007
@@ -625,7 +625,7 @@
              (ja-string-list-to-wide-alphabet 
                (if upper?
                    (map charcode->string
-                        (map char-upcase
+                        (map ichar-upcase
                              (map string->charcode
                                   (string-to-list (car raw-str-list)))))
                    (string-to-list (car raw-str-list))))
@@ -634,7 +634,7 @@
              (if upper?
                  (string-list-concat
                   (map charcode->string
-                       (map char-upcase
+                       (map ichar-upcase
                             (map string->charcode
                                  (string-to-list (car raw-str-list))))))
                  (car raw-str-list))
@@ -1013,7 +1013,7 @@
              (if (and
                   (= (mana-context-input-rule mc) mana-input-rule-roma)
                   (not (null? (ustr-former-seq preconv-str)))
-                  (not (char-printable?        ;; check for kana
+                  (not (ichar-printable?       ;; check for kana
                         (string->char
                          (car (last (ustr-former-seq preconv-str)))))))
                  (ja-fix-deleted-raw-str-to-valid-roma! raw-str)))))

Modified: trunk/scm/skk.scm
==============================================================================
--- trunk/scm/skk.scm   (original)
+++ trunk/scm/skk.scm   Wed Jul 11 06:07:04 2007
@@ -435,9 +435,9 @@
           (lambda (l)
             (let ((c (string->charcode (caar l))))
               (cond
-               ((char-upper-case? c)
+               ((ichar-upper-case? c)
                 (charcode->string (+ c 32)))
-               ((char-lower-case? c)
+               ((ichar-lower-case? c)
                 (charcode->string (- c 32)))
                (else
                 (caar l)))))))
@@ -963,7 +963,7 @@
      ((or
        (and
        (shift-key-mask key-state)
-       (not (char-graphic? key)))
+       (not (ichar-graphic? key)))
        (control-key-mask key-state)
        (alt-key-mask key-state)
        (meta-key-mask key-state)
@@ -1088,7 +1088,7 @@
        (if (or
            (and
             (shift-key-mask key-state)
-            (not (char-graphic? key)))
+            (not (ichar-graphic? key)))
            (control-key-mask key-state)
            (alt-key-mask key-state)
            (meta-key-mask key-state)
@@ -1099,7 +1099,7 @@
             (skk-commit-raw-with-preedit-update sc key key-state)
             #f)
           #t)
-       (if (char-upper-case? key)
+       (if (ichar-upper-case? key)
           (if (and 
                (skk-rk-pending? sc)
                (not (rk-current-seq rkc)))
@@ -1418,7 +1418,7 @@
             (skk-begin-conversion sc)
             #f)
           #t)
-       (if (and (char-upper-case? key)
+       (if (and (ichar-upper-case? key)
                (not (null? (skk-context-head sc))))
           (let ((key-str (charcode->string (to-lower-char key))))
             (set! res (skk-rk-push-key-match-without-new-seq rkc key-str))
@@ -2102,7 +2102,7 @@
               (set! idx (remainder idx skk-nr-candidate-max))
               (if (< idx (length skk-uim-heading-label-char-list))
                   (charcode->string
-                   (char-upcase
+                   (ichar-upcase
                     (string->charcode
                      (nth idx skk-uim-heading-label-char-list))))
                   ""))))
@@ -2111,7 +2111,7 @@
             (set! idx (remainder idx skk-nr-candidate-max)))
         (if (< idx (length skk-ddskk-like-heading-label-char-list))
             (charcode->string
-             (char-upcase
+             (ichar-upcase
               (string->charcode
                (nth idx skk-ddskk-like-heading-label-char-list))))
             "")))

Modified: trunk/test/test-util.scm
==============================================================================
--- trunk/test/test-util.scm    (original)
+++ trunk/test/test-util.scm    Wed Jul 11 06:07:04 2007
@@ -29,189 +29,189 @@
 ;;; SUCH DAMAGE.
 ;;;;
 
-;; These tests are passed at revision 4704 (new repository)
+;; These tests are passed at revision 4708 (new repository)
 
 (use test.unit)
 
 (require "test/uim-test-utils")
 
 (define-uim-test-case "testcase util character predicates"
-  ("test char-control?"
-   (assert-false (uim-bool '(char-control? 'symbol)))
-   (assert-false (uim-bool '(char-control? "string")))
-   (assert-false (uim-bool '(char-control? '(0 1 2))))
-   (assert-false (uim-bool '(char-control? car)))
-   (assert-true  (uim-bool '(char-control? 0)))    ; NUL
-   (assert-true  (uim-bool '(char-control? 1)))    ; SOH
-   (assert-true  (uim-bool '(char-control? 31)))   ; US
-   (assert-false (uim-bool '(char-control? 32)))   ; SPACE
-   (assert-false (uim-bool '(char-control? 33)))   ; !
-   (assert-false (uim-bool '(char-control? 47)))   ; /
-   (assert-false (uim-bool '(char-control? 48)))   ; 0
-   (assert-false (uim-bool '(char-control? 57)))   ; 9
-   (assert-false (uim-bool '(char-control? 58)))   ; :
-   (assert-false (uim-bool '(char-control? 64)))   ; @
-   (assert-false (uim-bool '(char-control? 65)))   ; A
-   (assert-false (uim-bool '(char-control? 90)))   ; Z
-   (assert-false (uim-bool '(char-control? 91)))   ; [
-   (assert-false (uim-bool '(char-control? 96)))   ; `
-   (assert-false (uim-bool '(char-control? 97)))   ; a
-   (assert-false (uim-bool '(char-control? 122)))  ; z
-   (assert-false (uim-bool '(char-control? 123)))  ; {
-   (assert-false (uim-bool '(char-control? 126)))  ; ~
-   (assert-true  (uim-bool '(char-control? 127)))) ; DEL
-  ("test char-upper-case?"
-   (assert-false (uim-bool '(char-upper-case? 'symbol)))
-   (assert-false (uim-bool '(char-upper-case? "string")))
-   (assert-false (uim-bool '(char-upper-case? '(0 1 2))))
-   (assert-false (uim-bool '(char-upper-case? car)))
-   (assert-false (uim-bool '(char-upper-case? 0)))    ; NUL
-   (assert-false (uim-bool '(char-upper-case? 1)))    ; SOH
-   (assert-false (uim-bool '(char-upper-case? 31)))   ; US
-   (assert-false (uim-bool '(char-upper-case? 32)))   ; SPACE
-   (assert-false (uim-bool '(char-upper-case? 33)))   ; !
-   (assert-false (uim-bool '(char-upper-case? 47)))   ; /
-   (assert-false (uim-bool '(char-upper-case? 48)))   ; 0
-   (assert-false (uim-bool '(char-upper-case? 57)))   ; 9
-   (assert-false (uim-bool '(char-upper-case? 58)))   ; :
-   (assert-false (uim-bool '(char-upper-case? 64)))   ; @
-   (assert-true  (uim-bool '(char-upper-case? 65)))   ; A
-   (assert-true  (uim-bool '(char-upper-case? 90)))   ; Z
-   (assert-false (uim-bool '(char-upper-case? 91)))   ; [
-   (assert-false (uim-bool '(char-upper-case? 96)))   ; `
-   (assert-false (uim-bool '(char-upper-case? 97)))   ; a
-   (assert-false (uim-bool '(char-upper-case? 122)))  ; z
-   (assert-false (uim-bool '(char-upper-case? 123)))  ; {
-   (assert-false (uim-bool '(char-upper-case? 126)))  ; ~
-   (assert-false (uim-bool '(char-upper-case? 127)))) ; DEL
-  ("test char-lower-case?"
-   (assert-false (uim-bool '(char-lower-case? 'symbol)))
-   (assert-false (uim-bool '(char-lower-case? "string")))
-   (assert-false (uim-bool '(char-lower-case? '(0 1 2))))
-   (assert-false (uim-bool '(char-lower-case? car)))
-   (assert-false (uim-bool '(char-lower-case? 0)))    ; NUL
-   (assert-false (uim-bool '(char-lower-case? 1)))    ; SOH
-   (assert-false (uim-bool '(char-lower-case? 31)))   ; US
-   (assert-false (uim-bool '(char-lower-case? 32)))   ; SPACE
-   (assert-false (uim-bool '(char-lower-case? 33)))   ; !
-   (assert-false (uim-bool '(char-lower-case? 47)))   ; /
-   (assert-false (uim-bool '(char-lower-case? 48)))   ; 0
-   (assert-false (uim-bool '(char-lower-case? 57)))   ; 9
-   (assert-false (uim-bool '(char-lower-case? 58)))   ; :
-   (assert-false (uim-bool '(char-lower-case? 64)))   ; @
-   (assert-false (uim-bool '(char-lower-case? 65)))   ; A
-   (assert-false (uim-bool '(char-lower-case? 90)))   ; Z
-   (assert-false (uim-bool '(char-lower-case? 91)))   ; [
-   (assert-false (uim-bool '(char-lower-case? 96)))   ; `
-   (assert-true  (uim-bool '(char-lower-case? 97)))   ; a
-   (assert-true  (uim-bool '(char-lower-case? 122)))  ; z
-   (assert-false (uim-bool '(char-lower-case? 123)))  ; {
-   (assert-false (uim-bool '(char-lower-case? 126)))  ; ~
-   (assert-false (uim-bool '(char-lower-case? 127)))) ; DEL
-  ("test char-alphabetic?"
-   (assert-false (uim-bool '(char-alphabetic? 'symbol)))
-   (assert-false (uim-bool '(char-alphabetic? "string")))
-   (assert-false (uim-bool '(char-alphabetic? '(0 1 2))))
-   (assert-false (uim-bool '(char-alphabetic? car)))
-   (assert-false (uim-bool '(char-alphabetic? 0)))    ; NUL
-   (assert-false (uim-bool '(char-alphabetic? 1)))    ; SOH
-   (assert-false (uim-bool '(char-alphabetic? 31)))   ; US
-   (assert-false (uim-bool '(char-alphabetic? 32)))   ; SPACE
-   (assert-false (uim-bool '(char-alphabetic? 33)))   ; !
-   (assert-false (uim-bool '(char-alphabetic? 47)))   ; /
-   (assert-false (uim-bool '(char-alphabetic? 48)))   ; 0
-   (assert-false (uim-bool '(char-alphabetic? 57)))   ; 9
-   (assert-false (uim-bool '(char-alphabetic? 58)))   ; :
-   (assert-false (uim-bool '(char-alphabetic? 64)))   ; @
-   (assert-true  (uim-bool '(char-alphabetic? 65)))   ; A
-   (assert-true  (uim-bool '(char-alphabetic? 90)))   ; Z
-   (assert-false (uim-bool '(char-alphabetic? 91)))   ; [
-   (assert-false (uim-bool '(char-alphabetic? 96)))   ; `
-   (assert-true  (uim-bool '(char-alphabetic? 97)))   ; a
-   (assert-true  (uim-bool '(char-alphabetic? 122)))  ; z
-   (assert-false (uim-bool '(char-alphabetic? 123)))  ; {
-   (assert-false (uim-bool '(char-alphabetic? 126)))  ; ~
-   (assert-false (uim-bool '(char-alphabetic? 127)))) ; DEL
-  ("test char-numeric?"
-   (assert-false (uim-bool '(char-numeric? 'symbol)))
-   (assert-false (uim-bool '(char-numeric? "string")))
-   (assert-false (uim-bool '(char-numeric? '(0 1 2))))
-   (assert-false (uim-bool '(char-numeric? car)))
-   (assert-false (uim-bool '(char-numeric? 0)))     ; NUL
-   (assert-false (uim-bool '(char-numeric? 1)))     ; SOH
-   (assert-false (uim-bool '(char-numeric? 31)))    ; US
-   (assert-false (uim-bool '(char-numeric? 32)))    ; SPACE
-   (assert-false (uim-bool '(char-numeric? 33)))    ; !
-   (assert-false (uim-bool '(char-numeric? 47)))    ; /
-   (assert-true  (uim-bool '(char-numeric? 48)))    ; 0
-   (assert-true  (uim-bool '(char-numeric? 57)))    ; 9
-   (assert-false (uim-bool '(char-numeric? 58)))    ; :
-   (assert-false (uim-bool '(char-numeric? 64)))    ; @
-   (assert-false (uim-bool '(char-numeric? 65)))    ; A
-   (assert-false (uim-bool '(char-numeric? 90)))    ; Z
-   (assert-false (uim-bool '(char-numeric? 91)))    ; [
-   (assert-false (uim-bool '(char-numeric? 96)))    ; `
-   (assert-false (uim-bool '(char-numeric? 97)))    ; a
-   (assert-false (uim-bool '(char-numeric? 122)))   ; z
-   (assert-false (uim-bool '(char-numeric? 123)))   ; {
-   (assert-false (uim-bool '(char-numeric? 126)))   ; ~
-   (assert-false (uim-bool '(char-numeric? 127)))) ; DEL
-  ("test char-printable?"
-   (assert-false (uim-bool '(char-printable? 'symbol)))
-   (assert-false (uim-bool '(char-printable? "string")))
-   (assert-false (uim-bool '(char-printable? '(0 1 2))))
-   (assert-false (uim-bool '(char-printable? car)))
-   (assert-false (uim-bool '(char-printable? 0)))    ; NUL
-   (assert-false (uim-bool '(char-printable? 1)))    ; SOH
-   (assert-false (uim-bool '(char-printable? 31)))   ; US
-   (assert-true  (uim-bool '(char-printable? 32)))   ; SPACE
-   (assert-true  (uim-bool '(char-printable? 33)))   ; !
-   (assert-true  (uim-bool '(char-printable? 47)))   ; /
-   (assert-true  (uim-bool '(char-printable? 48)))   ; 0
-   (assert-true  (uim-bool '(char-printable? 57)))   ; 9
-   (assert-true  (uim-bool '(char-printable? 58)))   ; :
-   (assert-true  (uim-bool '(char-printable? 64)))   ; @
-   (assert-true  (uim-bool '(char-printable? 65)))   ; A
-   (assert-true  (uim-bool '(char-printable? 90)))   ; Z
-   (assert-true  (uim-bool '(char-printable? 91)))   ; [
-   (assert-true  (uim-bool '(char-printable? 96)))   ; `
-   (assert-true  (uim-bool '(char-printable? 97)))   ; a
-   (assert-true  (uim-bool '(char-printable? 122)))  ; z
-   (assert-true  (uim-bool '(char-printable? 123)))  ; {
-   (assert-true  (uim-bool '(char-printable? 126)))  ; ~
-   (assert-false (uim-bool '(char-printable? 127)))) ; DEL
-  ("test char-graphic?"
-   (assert-false (uim-bool '(char-graphic? 'symbol)))
-   (assert-false (uim-bool '(char-graphic? "string")))
-   (assert-false (uim-bool '(char-graphic? '(0 1 2))))
-   (assert-false (uim-bool '(char-graphic? car)))
-   (assert-false (uim-bool '(char-graphic? 0)))    ; NUL
-   (assert-false (uim-bool '(char-graphic? 1)))    ; SOH
-   (assert-false (uim-bool '(char-graphic? 31)))   ; US
-   (assert-false (uim-bool '(char-graphic? 32)))   ; SPACE
-   (assert-true  (uim-bool '(char-graphic? 33)))   ; !
-   (assert-true  (uim-bool '(char-graphic? 47)))   ; /
-   (assert-true  (uim-bool '(char-graphic? 48)))   ; 0
-   (assert-true  (uim-bool '(char-graphic? 57)))   ; 9
-   (assert-true  (uim-bool '(char-graphic? 58)))   ; :
-   (assert-true  (uim-bool '(char-graphic? 64)))   ; @
-   (assert-true  (uim-bool '(char-graphic? 65)))   ; A
-   (assert-true  (uim-bool '(char-graphic? 90)))   ; Z
-   (assert-true  (uim-bool '(char-graphic? 91)))   ; [
-   (assert-true  (uim-bool '(char-graphic? 96)))   ; `
-   (assert-true  (uim-bool '(char-graphic? 97)))   ; a
-   (assert-true  (uim-bool '(char-graphic? 122)))  ; z
-   (assert-true  (uim-bool '(char-graphic? 123)))  ; {
-   (assert-true  (uim-bool '(char-graphic? 126)))  ; ~
-   (assert-false (uim-bool '(char-graphic? 127)))) ; DEL
+  ("test ichar-control?"
+   (assert-false (uim-bool '(ichar-control? 'symbol)))
+   (assert-false (uim-bool '(ichar-control? "string")))
+   (assert-false (uim-bool '(ichar-control? '(0 1 2))))
+   (assert-false (uim-bool '(ichar-control? car)))
+   (assert-true  (uim-bool '(ichar-control? 0)))    ; NUL
+   (assert-true  (uim-bool '(ichar-control? 1)))    ; SOH
+   (assert-true  (uim-bool '(ichar-control? 31)))   ; US
+   (assert-false (uim-bool '(ichar-control? 32)))   ; SPACE
+   (assert-false (uim-bool '(ichar-control? 33)))   ; !
+   (assert-false (uim-bool '(ichar-control? 47)))   ; /
+   (assert-false (uim-bool '(ichar-control? 48)))   ; 0
+   (assert-false (uim-bool '(ichar-control? 57)))   ; 9
+   (assert-false (uim-bool '(ichar-control? 58)))   ; :
+   (assert-false (uim-bool '(ichar-control? 64)))   ; @
+   (assert-false (uim-bool '(ichar-control? 65)))   ; A
+   (assert-false (uim-bool '(ichar-control? 90)))   ; Z
+   (assert-false (uim-bool '(ichar-control? 91)))   ; [
+   (assert-false (uim-bool '(ichar-control? 96)))   ; `
+   (assert-false (uim-bool '(ichar-control? 97)))   ; a
+   (assert-false (uim-bool '(ichar-control? 122)))  ; z
+   (assert-false (uim-bool '(ichar-control? 123)))  ; {
+   (assert-false (uim-bool '(ichar-control? 126)))  ; ~
+   (assert-true  (uim-bool '(ichar-control? 127)))) ; DEL
+  ("test ichar-upper-case?"
+   (assert-false (uim-bool '(ichar-upper-case? 'symbol)))
+   (assert-false (uim-bool '(ichar-upper-case? "string")))
+   (assert-false (uim-bool '(ichar-upper-case? '(0 1 2))))
+   (assert-false (uim-bool '(ichar-upper-case? car)))
+   (assert-false (uim-bool '(ichar-upper-case? 0)))    ; NUL
+   (assert-false (uim-bool '(ichar-upper-case? 1)))    ; SOH
+   (assert-false (uim-bool '(ichar-upper-case? 31)))   ; US
+   (assert-false (uim-bool '(ichar-upper-case? 32)))   ; SPACE
+   (assert-false (uim-bool '(ichar-upper-case? 33)))   ; !
+   (assert-false (uim-bool '(ichar-upper-case? 47)))   ; /
+   (assert-false (uim-bool '(ichar-upper-case? 48)))   ; 0
+   (assert-false (uim-bool '(ichar-upper-case? 57)))   ; 9
+   (assert-false (uim-bool '(ichar-upper-case? 58)))   ; :
+   (assert-false (uim-bool '(ichar-upper-case? 64)))   ; @
+   (assert-true  (uim-bool '(ichar-upper-case? 65)))   ; A
+   (assert-true  (uim-bool '(ichar-upper-case? 90)))   ; Z
+   (assert-false (uim-bool '(ichar-upper-case? 91)))   ; [
+   (assert-false (uim-bool '(ichar-upper-case? 96)))   ; `
+   (assert-false (uim-bool '(ichar-upper-case? 97)))   ; a
+   (assert-false (uim-bool '(ichar-upper-case? 122)))  ; z
+   (assert-false (uim-bool '(ichar-upper-case? 123)))  ; {
+   (assert-false (uim-bool '(ichar-upper-case? 126)))  ; ~
+   (assert-false (uim-bool '(ichar-upper-case? 127)))) ; DEL
+  ("test ichar-lower-case?"
+   (assert-false (uim-bool '(ichar-lower-case? 'symbol)))
+   (assert-false (uim-bool '(ichar-lower-case? "string")))
+   (assert-false (uim-bool '(ichar-lower-case? '(0 1 2))))
+   (assert-false (uim-bool '(ichar-lower-case? car)))
+   (assert-false (uim-bool '(ichar-lower-case? 0)))    ; NUL
+   (assert-false (uim-bool '(ichar-lower-case? 1)))    ; SOH
+   (assert-false (uim-bool '(ichar-lower-case? 31)))   ; US
+   (assert-false (uim-bool '(ichar-lower-case? 32)))   ; SPACE
+   (assert-false (uim-bool '(ichar-lower-case? 33)))   ; !
+   (assert-false (uim-bool '(ichar-lower-case? 47)))   ; /
+   (assert-false (uim-bool '(ichar-lower-case? 48)))   ; 0
+   (assert-false (uim-bool '(ichar-lower-case? 57)))   ; 9
+   (assert-false (uim-bool '(ichar-lower-case? 58)))   ; :
+   (assert-false (uim-bool '(ichar-lower-case? 64)))   ; @
+   (assert-false (uim-bool '(ichar-lower-case? 65)))   ; A
+   (assert-false (uim-bool '(ichar-lower-case? 90)))   ; Z
+   (assert-false (uim-bool '(ichar-lower-case? 91)))   ; [
+   (assert-false (uim-bool '(ichar-lower-case? 96)))   ; `
+   (assert-true  (uim-bool '(ichar-lower-case? 97)))   ; a
+   (assert-true  (uim-bool '(ichar-lower-case? 122)))  ; z
+   (assert-false (uim-bool '(ichar-lower-case? 123)))  ; {
+   (assert-false (uim-bool '(ichar-lower-case? 126)))  ; ~
+   (assert-false (uim-bool '(ichar-lower-case? 127)))) ; DEL
+  ("test ichar-alphabetic?"
+   (assert-false (uim-bool '(ichar-alphabetic? 'symbol)))
+   (assert-false (uim-bool '(ichar-alphabetic? "string")))
+   (assert-false (uim-bool '(ichar-alphabetic? '(0 1 2))))
+   (assert-false (uim-bool '(ichar-alphabetic? car)))
+   (assert-false (uim-bool '(ichar-alphabetic? 0)))    ; NUL
+   (assert-false (uim-bool '(ichar-alphabetic? 1)))    ; SOH
+   (assert-false (uim-bool '(ichar-alphabetic? 31)))   ; US
+   (assert-false (uim-bool '(ichar-alphabetic? 32)))   ; SPACE
+   (assert-false (uim-bool '(ichar-alphabetic? 33)))   ; !
+   (assert-false (uim-bool '(ichar-alphabetic? 47)))   ; /
+   (assert-false (uim-bool '(ichar-alphabetic? 48)))   ; 0
+   (assert-false (uim-bool '(ichar-alphabetic? 57)))   ; 9
+   (assert-false (uim-bool '(ichar-alphabetic? 58)))   ; :
+   (assert-false (uim-bool '(ichar-alphabetic? 64)))   ; @
+   (assert-true  (uim-bool '(ichar-alphabetic? 65)))   ; A
+   (assert-true  (uim-bool '(ichar-alphabetic? 90)))   ; Z
+   (assert-false (uim-bool '(ichar-alphabetic? 91)))   ; [
+   (assert-false (uim-bool '(ichar-alphabetic? 96)))   ; `
+   (assert-true  (uim-bool '(ichar-alphabetic? 97)))   ; a
+   (assert-true  (uim-bool '(ichar-alphabetic? 122)))  ; z
+   (assert-false (uim-bool '(ichar-alphabetic? 123)))  ; {
+   (assert-false (uim-bool '(ichar-alphabetic? 126)))  ; ~
+   (assert-false (uim-bool '(ichar-alphabetic? 127)))) ; DEL
+  ("test ichar-numeric?"
+   (assert-false (uim-bool '(ichar-numeric? 'symbol)))
+   (assert-false (uim-bool '(ichar-numeric? "string")))
+   (assert-false (uim-bool '(ichar-numeric? '(0 1 2))))
+   (assert-false (uim-bool '(ichar-numeric? car)))
+   (assert-false (uim-bool '(ichar-numeric? 0)))     ; NUL
+   (assert-false (uim-bool '(ichar-numeric? 1)))     ; SOH
+   (assert-false (uim-bool '(ichar-numeric? 31)))    ; US
+   (assert-false (uim-bool '(ichar-numeric? 32)))    ; SPACE
+   (assert-false (uim-bool '(ichar-numeric? 33)))    ; !
+   (assert-false (uim-bool '(ichar-numeric? 47)))    ; /
+   (assert-true  (uim-bool '(ichar-numeric? 48)))    ; 0
+   (assert-true  (uim-bool '(ichar-numeric? 57)))    ; 9
+   (assert-false (uim-bool '(ichar-numeric? 58)))    ; :
+   (assert-false (uim-bool '(ichar-numeric? 64)))    ; @
+   (assert-false (uim-bool '(ichar-numeric? 65)))    ; A
+   (assert-false (uim-bool '(ichar-numeric? 90)))    ; Z
+   (assert-false (uim-bool '(ichar-numeric? 91)))    ; [
+   (assert-false (uim-bool '(ichar-numeric? 96)))    ; `
+   (assert-false (uim-bool '(ichar-numeric? 97)))    ; a
+   (assert-false (uim-bool '(ichar-numeric? 122)))   ; z
+   (assert-false (uim-bool '(ichar-numeric? 123)))   ; {
+   (assert-false (uim-bool '(ichar-numeric? 126)))   ; ~
+   (assert-false (uim-bool '(ichar-numeric? 127)))) ; DEL
+  ("test ichar-printable?"
+   (assert-false (uim-bool '(ichar-printable? 'symbol)))
+   (assert-false (uim-bool '(ichar-printable? "string")))
+   (assert-false (uim-bool '(ichar-printable? '(0 1 2))))
+   (assert-false (uim-bool '(ichar-printable? car)))
+   (assert-false (uim-bool '(ichar-printable? 0)))    ; NUL
+   (assert-false (uim-bool '(ichar-printable? 1)))    ; SOH
+   (assert-false (uim-bool '(ichar-printable? 31)))   ; US
+   (assert-true  (uim-bool '(ichar-printable? 32)))   ; SPACE
+   (assert-true  (uim-bool '(ichar-printable? 33)))   ; !
+   (assert-true  (uim-bool '(ichar-printable? 47)))   ; /
+   (assert-true  (uim-bool '(ichar-printable? 48)))   ; 0
+   (assert-true  (uim-bool '(ichar-printable? 57)))   ; 9
+   (assert-true  (uim-bool '(ichar-printable? 58)))   ; :
+   (assert-true  (uim-bool '(ichar-printable? 64)))   ; @
+   (assert-true  (uim-bool '(ichar-printable? 65)))   ; A
+   (assert-true  (uim-bool '(ichar-printable? 90)))   ; Z
+   (assert-true  (uim-bool '(ichar-printable? 91)))   ; [
+   (assert-true  (uim-bool '(ichar-printable? 96)))   ; `
+   (assert-true  (uim-bool '(ichar-printable? 97)))   ; a
+   (assert-true  (uim-bool '(ichar-printable? 122)))  ; z
+   (assert-true  (uim-bool '(ichar-printable? 123)))  ; {
+   (assert-true  (uim-bool '(ichar-printable? 126)))  ; ~
+   (assert-false (uim-bool '(ichar-printable? 127)))) ; DEL
+  ("test ichar-graphic?"
+   (assert-false (uim-bool '(ichar-graphic? 'symbol)))
+   (assert-false (uim-bool '(ichar-graphic? "string")))
+   (assert-false (uim-bool '(ichar-graphic? '(0 1 2))))
+   (assert-false (uim-bool '(ichar-graphic? car)))
+   (assert-false (uim-bool '(ichar-graphic? 0)))    ; NUL
+   (assert-false (uim-bool '(ichar-graphic? 1)))    ; SOH
+   (assert-false (uim-bool '(ichar-graphic? 31)))   ; US
+   (assert-false (uim-bool '(ichar-graphic? 32)))   ; SPACE
+   (assert-true  (uim-bool '(ichar-graphic? 33)))   ; !
+   (assert-true  (uim-bool '(ichar-graphic? 47)))   ; /
+   (assert-true  (uim-bool '(ichar-graphic? 48)))   ; 0
+   (assert-true  (uim-bool '(ichar-graphic? 57)))   ; 9
+   (assert-true  (uim-bool '(ichar-graphic? 58)))   ; :
+   (assert-true  (uim-bool '(ichar-graphic? 64)))   ; @
+   (assert-true  (uim-bool '(ichar-graphic? 65)))   ; A
+   (assert-true  (uim-bool '(ichar-graphic? 90)))   ; Z
+   (assert-true  (uim-bool '(ichar-graphic? 91)))   ; [
+   (assert-true  (uim-bool '(ichar-graphic? 96)))   ; `
+   (assert-true  (uim-bool '(ichar-graphic? 97)))   ; a
+   (assert-true  (uim-bool '(ichar-graphic? 122)))  ; z
+   (assert-true  (uim-bool '(ichar-graphic? 123)))  ; {
+   (assert-true  (uim-bool '(ichar-graphic? 126)))  ; ~
+   (assert-false (uim-bool '(ichar-graphic? 127)))) ; DEL
   ("test control-char?"
-   (assert-true  (uim-bool '(eq? control-char? char-control?))))
+   (assert-true  (uim-bool '(eq? control-char? ichar-control?))))
   ("test alphabet-char?"
-   (assert-true  (uim-bool '(eq? alphabet-char? char-alphabetic?))))
+   (assert-true  (uim-bool '(eq? alphabet-char? ichar-alphabetic?))))
   ("test numeral-char?"
-   (assert-true  (uim-bool '(eq? numeral-char? char-numeric?))))
+   (assert-true  (uim-bool '(eq? numeral-char? ichar-numeric?))))
   ("test usual-char?"
-   (assert-true  (uim-bool '(eq? usual-char? char-graphic?)))))
+   (assert-true  (uim-bool '(eq? usual-char? ichar-graphic?)))))
 
 (define-uim-test-case "test util character conversion procedures"
   ("test numeral-char->number"
@@ -242,46 +242,46 @@
    (assert-true  (uim-bool '(integer? (numeral-char->number 123))))  ; {
    (assert-true  (uim-bool '(integer? (numeral-char->number 126))))  ; ~
    (assert-true  (uim-bool '(integer? (numeral-char->number 127))))) ; DEL
-  ("test char-downcase"
-   (assert-equal 0   (uim '(char-downcase 0)))     ; NUL
-   (assert-equal 1   (uim '(char-downcase 1)))     ; SOH
-   (assert-equal 31  (uim '(char-downcase 31)))    ; US
-   (assert-equal 32  (uim '(char-downcase 32)))    ; SPACE
-   (assert-equal 33  (uim '(char-downcase 33)))    ; !
-   (assert-equal 47  (uim '(char-downcase 47)))    ; /
-   (assert-equal 48  (uim '(char-downcase 48)))    ; 0
-   (assert-equal 57  (uim '(char-downcase 57)))    ; 9
-   (assert-equal 58  (uim '(char-downcase 58)))    ; :
-   (assert-equal 64  (uim '(char-downcase 64)))    ; @
-   (assert-equal 97  (uim '(char-downcase 65)))    ; A
-   (assert-equal 122 (uim '(char-downcase 90)))    ; Z
-   (assert-equal 91  (uim '(char-downcase 91)))    ; [
-   (assert-equal 96  (uim '(char-downcase 96)))    ; `
-   (assert-equal 97  (uim '(char-downcase 97)))    ; a
-   (assert-equal 122 (uim '(char-downcase 122)))   ; z
-   (assert-equal 123 (uim '(char-downcase 123)))   ; {
-   (assert-equal 126 (uim '(char-downcase 126)))   ; ~
-   (assert-equal 127 (uim '(char-downcase 127))))  ; DEL
-  ("test char-upcase"
-   (assert-equal 0   (uim '(char-upcase 0)))     ; NUL
-   (assert-equal 1   (uim '(char-upcase 1)))     ; SOH
-   (assert-equal 31  (uim '(char-upcase 31)))    ; US
-   (assert-equal 32  (uim '(char-upcase 32)))    ; SPACE
-   (assert-equal 33  (uim '(char-upcase 33)))    ; !
-   (assert-equal 47  (uim '(char-upcase 47)))    ; /
-   (assert-equal 48  (uim '(char-upcase 48)))    ; 0
-   (assert-equal 57  (uim '(char-upcase 57)))    ; 9
-   (assert-equal 58  (uim '(char-upcase 58)))    ; :
-   (assert-equal 64  (uim '(char-upcase 64)))    ; @
-   (assert-equal 65  (uim '(char-upcase 65)))    ; A
-   (assert-equal 90  (uim '(char-upcase 90)))    ; Z
-   (assert-equal 91  (uim '(char-upcase 91)))    ; [
-   (assert-equal 96  (uim '(char-upcase 96)))    ; `
-   (assert-equal 65  (uim '(char-upcase 97)))    ; a
-   (assert-equal 90  (uim '(char-upcase 122)))   ; z
-   (assert-equal 123 (uim '(char-upcase 123)))   ; {
-   (assert-equal 126 (uim '(char-upcase 126)))   ; ~
-   (assert-equal 127 (uim '(char-upcase 127))))  ; DEL
+  ("test ichar-downcase"
+   (assert-equal 0   (uim '(ichar-downcase 0)))     ; NUL
+   (assert-equal 1   (uim '(ichar-downcase 1)))     ; SOH
+   (assert-equal 31  (uim '(ichar-downcase 31)))    ; US
+   (assert-equal 32  (uim '(ichar-downcase 32)))    ; SPACE
+   (assert-equal 33  (uim '(ichar-downcase 33)))    ; !
+   (assert-equal 47  (uim '(ichar-downcase 47)))    ; /
+   (assert-equal 48  (uim '(ichar-downcase 48)))    ; 0
+   (assert-equal 57  (uim '(ichar-downcase 57)))    ; 9
+   (assert-equal 58  (uim '(ichar-downcase 58)))    ; :
+   (assert-equal 64  (uim '(ichar-downcase 64)))    ; @
+   (assert-equal 97  (uim '(ichar-downcase 65)))    ; A
+   (assert-equal 122 (uim '(ichar-downcase 90)))    ; Z
+   (assert-equal 91  (uim '(ichar-downcase 91)))    ; [
+   (assert-equal 96  (uim '(ichar-downcase 96)))    ; `
+   (assert-equal 97  (uim '(ichar-downcase 97)))    ; a
+   (assert-equal 122 (uim '(ichar-downcase 122)))   ; z
+   (assert-equal 123 (uim '(ichar-downcase 123)))   ; {
+   (assert-equal 126 (uim '(ichar-downcase 126)))   ; ~
+   (assert-equal 127 (uim '(ichar-downcase 127))))  ; DEL
+  ("test ichar-upcase"
+   (assert-equal 0   (uim '(ichar-upcase 0)))     ; NUL
+   (assert-equal 1   (uim '(ichar-upcase 1)))     ; SOH
+   (assert-equal 31  (uim '(ichar-upcase 31)))    ; US
+   (assert-equal 32  (uim '(ichar-upcase 32)))    ; SPACE
+   (assert-equal 33  (uim '(ichar-upcase 33)))    ; !
+   (assert-equal 47  (uim '(ichar-upcase 47)))    ; /
+   (assert-equal 48  (uim '(ichar-upcase 48)))    ; 0
+   (assert-equal 57  (uim '(ichar-upcase 57)))    ; 9
+   (assert-equal 58  (uim '(ichar-upcase 58)))    ; :
+   (assert-equal 64  (uim '(ichar-upcase 64)))    ; @
+   (assert-equal 65  (uim '(ichar-upcase 65)))    ; A
+   (assert-equal 90  (uim '(ichar-upcase 90)))    ; Z
+   (assert-equal 91  (uim '(ichar-upcase 91)))    ; [
+   (assert-equal 96  (uim '(ichar-upcase 96)))    ; `
+   (assert-equal 65  (uim '(ichar-upcase 97)))    ; a
+   (assert-equal 90  (uim '(ichar-upcase 122)))   ; z
+   (assert-equal 123 (uim '(ichar-upcase 123)))   ; {
+   (assert-equal 126 (uim '(ichar-upcase 126)))   ; ~
+   (assert-equal 127 (uim '(ichar-upcase 127))))  ; DEL
   ("test string->letter"
    (assert-false (uim-bool '(string->letter "")))    ; NUL
    ;; FIXME: Since these control chars are normalized to "\x01" and so on by
@@ -310,7 +310,7 @@
    ;;(assert-false (uim-bool '(string->letter ""))) ; DEL
    )
   ("test to-lower-char"
-   (assert-true  (uim-bool '(eq? to-lower-char char-downcase)))))
+   (assert-true  (uim-bool '(eq? to-lower-char ichar-downcase)))))
 
 (define-uim-test-case "test util string list procedures"
   ("test string-list-concat"

Reply via email to
--- trunk/scm/byeoru.scm        (original)
+++ trunk/scm/byeoru.scm        Wed Jul 11 06:07:04 2007
@@ -1310,7 +1310,7 @@
               (charcode->string
                ;; avoid case change due to caps lock.
                (if (shift-key-mask key-state)
-                   (char-upcase key) (char-downcase key))))
+                   (ichar-upcase key) (ichar-downcase key))))
              (entry (assoc pressed-key layout)))
         (and entry
              (let ((choices (cdr entry)))
@@ -1814,7 +1814,7 @@
 
 (define (byeoru-key-press-handler bc key key-state)
 
 ;;    (if (char-control? key)      ; doesn't seem to work.
 ;;     (im-commit-raw bc)
 
   (if (byeoru-context-on bc)
@@ -1828,7 +1828,7 @@
   (byeoru-update-preedit bc))
 
 (define (byeoru-key-release-handler bc key key-state)
-  (if (or (char-control? key)
+  (if (or (ichar-control? key)
          (not (byeoru-context-on bc)))
       ;; don't discard key release event for apps
       (im-commit-raw bc)))
@@ -1814,7 +1814,7 @@
 (define (byeoru-key-press-handler bc key key-state)
 
-;;    (if (char-control? key)      ; doesn't seem to work.
+;;    (if (ichar-control? key)     ; doesn't seem to work.
 ;;     (im-commit-raw bc)
 

Modified: trunk/scm/canna.scm
==============================================================================